@@ -18,9 +18,17 @@
 package opennlp.tools.cmdline.doccat;
 
 import opennlp.tools.cmdline.AbstractConverterTool;
+import opennlp.tools.cmdline.params.BasicFormatParams;
 import opennlp.tools.doccat.DocumentSample;
 
-public class DoccatConverterTool extends AbstractConverterTool<DocumentSample> {
+/**
+ * Tool to convert multiple data formats into native OpenNLP doccat training
+ * format.
+ *
+ * @see AbstractConverterTool
+ * @see DocumentSample
+ */
+public class DoccatConverterTool extends AbstractConverterTool<DocumentSample, BasicFormatParams> {
 
   public DoccatConverterTool() {
     super(DocumentSample.class);
