@@ -22,6 +22,9 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.cmdline.BasicCmdLineTool;
 import opennlp.tools.cmdline.CLI;
 import opennlp.tools.cmdline.CmdLineUtil;
@@ -38,19 +41,21 @@ import opennlp.tools.util.Span;
 
 public class EntityLinkerTool extends BasicCmdLineTool {
 
+  private static final Logger logger = LoggerFactory.getLogger(EntityLinkerTool.class);
+
   @Override
   public String getShortDescription() {
-    return "links an entity to an external data set";
+    return "Links an entity to an external data set";
   }
 
   @Override
   public void run(String[] args) {
 
     if (0 == args.length) {
-      System.out.println(getHelp());
+      logger.info(getHelp());
     }
     else {
-      // TODO: Ask Mark if we can remove the type, the user knows upfront if he tries
+      // TODO: Ask Mark if we can remove the type, the user knows upfront if s/he tries
       // to link place names or company mentions ...
       String entityType = "location";
 
@@ -68,7 +73,7 @@ public class EntityLinkerTool extends BasicCmdLineTool {
 
       // TODO: It should not just throw Exception.
 
-      EntityLinker entityLinker;
+      EntityLinker<? extends Span> entityLinker;
       try {
         entityLinker = EntityLinkerFactory.getLinker(entityType, properties);
       }
@@ -76,7 +81,7 @@ public class EntityLinkerTool extends BasicCmdLineTool {
         throw new TerminateToolException(-1, "Failed to instantiate the Entity Linker: " + e.getMessage());
       }
 
-      PerformanceMonitor perfMon = new PerformanceMonitor(System.err, "sent");
+      PerformanceMonitor perfMon = new PerformanceMonitor("sent");
       perfMon.start();
 
       try (ObjectStream<String> untokenizedLineStream = new PlainTextByLineStream(
@@ -119,11 +124,11 @@ public class EntityLinkerTool extends BasicCmdLineTool {
               text.append("\n");
             }
 
-            List<Span> linkedSpans =
+            List<? extends  Span> linkedSpans =
                 entityLinker.find(text.toString(), sentences, tokensBySentence, namesBySentence);
 
             for (Span linkedSpan : linkedSpans) {
-              System.out.println(linkedSpan);
+              logger.info(linkedSpan.toString());
             }
 
             perfMon.incrementCounter(document.size());
