@@ -136,7 +136,7 @@ public final class LanguageDetectorEvaluatorTool extends
       reportListener.writeReport();
 
       try {
-        // TODO: is it a problem to close the stream now?
+        reportOutputStream.flush();
         reportOutputStream.close();
       } catch (IOException e) {
         // nothing to do
