@@ -21,13 +21,15 @@ import java.io.IOException;
 import java.io.InputStream;
 
 import opennlp.tools.cmdline.ModelLoader;
+import opennlp.tools.commons.Internal;
 import opennlp.tools.postag.POSModel;
 
 /**
- * Loads a POS Tagger Model for the command line tools.
+ * Loads a {@link POSModel} for the command line tools.
  * <p>
  * <b>Note:</b> Do not use this class, internal use only!
  */
+@Internal
 public final class POSModelLoader extends ModelLoader<POSModel> {
 
   public POSModelLoader() {
