@@ -18,7 +18,6 @@
 package opennlp.tools.formats;
 
 import java.io.IOException;
-import java.io.PrintStream;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.StandardCharsets;
 
@@ -27,14 +26,19 @@ import opennlp.tools.cmdline.CmdLineUtil;
 import opennlp.tools.cmdline.StreamFactoryRegistry;
 import opennlp.tools.cmdline.TerminateToolException;
 import opennlp.tools.cmdline.params.BasicFormatParams;
+import opennlp.tools.commons.Internal;
 import opennlp.tools.postag.POSSample;
 import opennlp.tools.util.InputStreamFactory;
 import opennlp.tools.util.ObjectStream;
 
 /**
- * <b>Note:</b> Do not use this class, internal use only!
+ * <b>Note:</b>
+ * Do not use this class, internal use only!
+ *
+ * @see ConllXPOSSampleStream
  */
-public class ConllXPOSSampleStreamFactory extends AbstractSampleStreamFactory<POSSample> {
+@Internal
+public class ConllXPOSSampleStreamFactory<P> extends AbstractSampleStreamFactory<POSSample, P> {
 
   public static final String CONLLX_FORMAT = "conllx";
 
@@ -43,13 +47,14 @@ public class ConllXPOSSampleStreamFactory extends AbstractSampleStreamFactory<PO
 
   public static void registerFactory() {
     StreamFactoryRegistry.registerFactory(POSSample.class,
-        CONLLX_FORMAT, new ConllXPOSSampleStreamFactory(Parameters.class));
+        CONLLX_FORMAT, new ConllXPOSSampleStreamFactory<>(Parameters.class));
   }
 
-  protected <P> ConllXPOSSampleStreamFactory(Class<P> params) {
+  protected ConllXPOSSampleStreamFactory(Class<P> params) {
     super(params);
   }
 
+  @Override
   public ObjectStream<POSSample> create(String[] args) {
     Parameters params = ArgumentParser.parse(args, Parameters.class);
 
@@ -57,8 +62,6 @@ public class ConllXPOSSampleStreamFactory extends AbstractSampleStreamFactory<PO
         CmdLineUtil.createInputStreamFactory(params.getData());
 
     try {
-      System.setOut(new PrintStream(System.out, true, StandardCharsets.UTF_8.name()));
-
       return new ConllXPOSSampleStream(inFactory, StandardCharsets.UTF_8);
     } catch (UnsupportedEncodingException e) {
       // this shouldn't happen
