@@ -26,6 +26,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.namefind.NameSample;
 import opennlp.tools.sentdetect.SentenceDetector;
 import opennlp.tools.tokenize.Tokenizer;
@@ -33,8 +36,10 @@ import opennlp.tools.util.Span;
 
 public class BratDocumentParser {
 
-  private SentenceDetector sentDetector;
-  private Tokenizer tokenizer;
+  private static final Logger logger = LoggerFactory.getLogger(BratDocumentParser.class);
+
+  private final SentenceDetector sentDetector;
+  private final Tokenizer tokenizer;
   private final Set<String> nameTypes;
 
   public BratDocumentParser(SentenceDetector sentenceDetector, Tokenizer tokenizer) {
@@ -86,8 +91,7 @@ public class BratDocumentParser {
         Span lastSentence = sentences.remove(sentences.size() - 1);
         sentences.add(new Span(lastSentence.getStart(), sentence.getEnd()));
 
-        System.out.println("Correcting sentence segmentation in document " +
-            sample.getId());
+        logger.info("Correcting sentence segmentation in document {}", sample.getId());
       }
       else {
         sentences.add(sentence);
@@ -144,9 +148,9 @@ public class BratDocumentParser {
               if (nameBeginIndex != null && nameEndIndex != null) {
                 mappedFragments.add(new Span(nameBeginIndex, nameEndIndex, entity.getType()));
               } else {
-                System.err.println("Dropped entity " + entity.getId() + " ("
-                    + entitySpan.getCoveredText(sample.getText()) + ") " + " in document "
-                    + sample.getId() + ", it is not matching tokenization!");
+                logger.warn("Dropped entity {} ({}) in document {} as it is not matching " +
+                        "tokenization!", entity.getId(),
+                    entitySpan.getCoveredText(sample.getText()), sample.getId());
               }
             }
           }
@@ -171,12 +175,12 @@ public class BratDocumentParser {
       }
 
       samples.add(new NameSample(sample.getId(), Span.spansToStrings(tokens, sentenceText),
-          names.toArray(new Span[names.size()]), null, samples.size() == 0));
+          names.toArray(new Span[0]), null, samples.size() == 0));
     }
 
     for (String id : entityIdSet) {
-      System.err.println("Dropped entity " + id + " in document " +
-          sample.getId() + ", is not matching sentence segmentation!");
+      logger.warn("Dropped entity {} in document {}"
+              + ", is not matching sentence segmentation!", id, sample.getId());
     }
 
     return samples;
