@@ -20,10 +20,10 @@ package opennlp.tools.ml;
 import java.io.IOException;
 
 import opennlp.tools.ml.model.AbstractDataIndexer;
+import opennlp.tools.ml.model.ChecksumEventStream;
 import opennlp.tools.ml.model.DataIndexer;
 import opennlp.tools.ml.model.DataIndexerFactory;
 import opennlp.tools.ml.model.Event;
-import opennlp.tools.ml.model.HashSumEventStream;
 import opennlp.tools.ml.model.MaxentModel;
 import opennlp.tools.util.InsufficientTrainingDataException;
 import opennlp.tools.util.ObjectStream;
@@ -57,8 +57,8 @@ public abstract class AbstractEventTrainer extends AbstractTrainer implements Ev
 
     trainingParameters.put(AbstractDataIndexer.SORT_PARAM, isSortAndMerge());
     // If the cutoff was set, don't overwrite the value.
-    if (trainingParameters.getIntParameter(CUTOFF_PARAM, -1) == -1) {
-      trainingParameters.put(CUTOFF_PARAM, 5);
+    if (trainingParameters.getIntParameter(TrainingParameters.CUTOFF_PARAM, -1) == -1) {
+      trainingParameters.put(TrainingParameters.CUTOFF_PARAM, TrainingParameters.CUTOFF_DEFAULT_VALUE);
     }
     
     DataIndexer indexer = DataIndexerFactory.getDataIndexer(trainingParameters, reportMap);
@@ -77,7 +77,7 @@ public abstract class AbstractEventTrainer extends AbstractTrainer implements Ev
     }
 
     MaxentModel model = doTrain(indexer);
-    addToReport(AbstractTrainer.TRAINER_TYPE_PARAM, EventTrainer.EVENT_VALUE);
+    addToReport(TrainingParameters.TRAINER_TYPE_PARAM, EventTrainer.EVENT_VALUE);
     return model;
   }
 
@@ -85,10 +85,10 @@ public abstract class AbstractEventTrainer extends AbstractTrainer implements Ev
   public final MaxentModel train(ObjectStream<Event> events) throws IOException {
     validate();
 
-    HashSumEventStream hses = new HashSumEventStream(events);
+    ChecksumEventStream hses = new ChecksumEventStream(events);
     DataIndexer indexer = getDataIndexer(hses);
 
-    addToReport("Training-Eventhash", hses.calculateHashSum().toString(16));
+    addToReport("Training-Eventhash", String.valueOf(hses.calculateChecksum()));
     return train(indexer);
   }
 }
