@@ -287,8 +287,8 @@ public class GISTrainer extends AbstractEventTrainer {
                              int cutoff) throws IOException {
     DataIndexer indexer = new OnePassDataIndexer();
     TrainingParameters indexingParameters = new TrainingParameters();
-    indexingParameters.put(GISTrainer.CUTOFF_PARAM, cutoff);
-    indexingParameters.put(GISTrainer.ITERATIONS_PARAM, iterations);
+    indexingParameters.put(TrainingParameters.CUTOFF_PARAM, cutoff);
+    indexingParameters.put(TrainingParameters.ITERATIONS_PARAM, iterations);
     Map<String, String> reportMap = new HashMap<>();
     indexer.init(indexingParameters, reportMap);
     indexer.index(eventStream);
