@@ -17,7 +17,6 @@
 
 package opennlp.tools.namefind;
 
-import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -44,9 +43,7 @@ import opennlp.tools.util.SequenceCodec;
 import opennlp.tools.util.SequenceValidator;
 import opennlp.tools.util.Span;
 import opennlp.tools.util.TrainingParameters;
-import opennlp.tools.util.featuregen.AdaptiveFeatureGenerator;
 import opennlp.tools.util.featuregen.AdditionalContextFeatureGenerator;
-import opennlp.tools.util.featuregen.GeneratorFactory;
 import opennlp.tools.util.featuregen.WindowFeatureGenerator;
 
 /**
@@ -64,7 +61,7 @@ public class NameFinderME implements TokenNameFinder {
 
   private final SequenceCodec<String> seqCodec;
 
-  protected final SequenceClassificationModel<String> model;
+  protected final SequenceClassificationModel model;
 
   protected final NameContextGenerator contextGenerator;
   private Sequence bestSequence;
@@ -92,26 +89,6 @@ public class NameFinderME implements TokenNameFinder {
             new WindowFeatureGenerator(additionalContextFeatureGenerator, 8, 8));
   }
 
-  private static AdaptiveFeatureGenerator createFeatureGenerator(
-          byte[] generatorDescriptor, final Map<String, Object> resources)
-          throws IOException {
-    AdaptiveFeatureGenerator featureGenerator;
-
-    if (generatorDescriptor != null) {
-      featureGenerator = GeneratorFactory.create(new ByteArrayInputStream(
-          generatorDescriptor), key -> {
-            if (resources != null) {
-              return resources.get(key);
-            }
-            return null;
-          });
-    } else {
-      featureGenerator = null;
-    }
-
-    return featureGenerator;
-  }
-
   @Override
   public Span[] find(String[] tokens) {
     return find(tokens, EMPTY);
@@ -244,7 +221,7 @@ public class NameFinderME implements TokenNameFinder {
     Map<String, String> manifestInfoEntries = new HashMap<>();
 
     MaxentModel nameFinderModel = null;
-    SequenceClassificationModel<String> seqModel = null;
+    SequenceClassificationModel seqModel = null;
 
     TrainerType trainerType = TrainerFactory.getTrainerType(params);
 
@@ -259,7 +236,7 @@ public class NameFinderME implements TokenNameFinder {
     else if (TrainerType.EVENT_MODEL_SEQUENCE_TRAINER.equals(trainerType)) {
       NameSampleSequenceStream ss = new NameSampleSequenceStream(samples, factory.createContextGenerator());
 
-      EventModelSequenceTrainer trainer = TrainerFactory.getEventModelSequenceTrainer(
+      EventModelSequenceTrainer<NameSample> trainer = TrainerFactory.getEventModelSequenceTrainer(
               params, manifestInfoEntries);
       nameFinderModel = trainer.train(ss);
     } else if (TrainerType.SEQUENCE_TRAINER.equals(trainerType)) {
