@@ -22,6 +22,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import opennlp.tools.dictionary.Dictionary;
 import opennlp.tools.ml.model.Event;
 import opennlp.tools.parser.AbstractBottomUpParser;
@@ -32,19 +35,48 @@ import opennlp.tools.parser.ParserEventTypeEnum;
 import opennlp.tools.util.ObjectStream;
 import opennlp.tools.util.Span;
 
+
+/**
+ * Wrapper class for one of four {@link Parser built-attach parser} event streams.
+ * The particular {@link ParserEventTypeEnum event type} is specified at construction.
+ */
 public class ParserEventStream extends AbstractParserEventStream {
 
+  private static final Logger logger = LoggerFactory.getLogger(ParserEventStream.class);
   protected AttachContextGenerator attachContextGenerator;
   protected BuildContextGenerator buildContextGenerator;
   protected CheckContextGenerator checkContextGenerator;
 
-  private static final boolean debug = false;
-
+  /**
+   * Instantiates a {@link ParserEventStream} based on the specified data stream
+   * of the {@link ParserEventTypeEnum type} using {@link HeadRules head rules}.
+   *
+   * @param d A 1-parse-per-line Penn Treebank Style parse.
+   * @param rules The {@link HeadRules head rules} to use.
+   * @param etype The {@link ParserEventTypeEnum type} of events desired.
+   * @param dict A tri-gram {@link Dictionary} to reduce feature generation.
+   *
+   * @see ParserEventTypeEnum
+   */
   public ParserEventStream(ObjectStream<Parse> d, HeadRules rules,
       ParserEventTypeEnum etype, Dictionary dict) {
     super(d, rules, etype, dict);
   }
 
+  /**
+   * Instantiates a {@link ParserEventStream} based on the specified data stream
+   * of the {@link ParserEventTypeEnum type} using {@link HeadRules head rules}.
+   *
+   * @param d A 1-parse-per-line Penn Treebank Style parse.
+   * @param rules The {@link HeadRules head rules} to use.
+   * @param etype The {@link ParserEventTypeEnum type} of events desired.
+   *
+   * @see ParserEventTypeEnum
+   */
+  public ParserEventStream(ObjectStream<Parse> d, HeadRules rules, ParserEventTypeEnum etype) {
+    super(d, rules, etype);
+  }
+
   @Override
   public void init() {
     buildContextGenerator = new BuildContextGenerator();
@@ -52,16 +84,13 @@ public class ParserEventStream extends AbstractParserEventStream {
     checkContextGenerator = new CheckContextGenerator(punctSet);
   }
 
-  public ParserEventStream(ObjectStream<Parse> d, HeadRules rules, ParserEventTypeEnum etype) {
-    super(d, rules, etype);
-  }
-
   /**
-   * Returns a set of parent nodes which consist of the immediate
-   * parent of the specified node and any of its parent which
+   * Returns a map of parent nodes which consist of the immediate
+   * parent of the specified {@link Parse node} and any of its parent which
    * share the same syntactic type.
-   * @param node The node whose parents are to be returned.
-   * @return a set of parent nodes.
+   * 
+   * @param node The {@link Parse node} whose parents are to be returned.
+   * @return A {@link Map} of parent {@link Parse nodes}.
    */
   private Map<Parse, Integer> getNonAdjoinedParent(Parse node) {
     Map<Parse, Integer> parents = new HashMap<>();
@@ -90,18 +119,6 @@ public class ParserEventStream extends AbstractParserEventStream {
   private int nonPunctChildCount(Parse node) {
     return Parser.collapsePunctuation(node.getChildren(),punctSet).length;
   }
-  /*
-  private Set getNonAdjoinedParent(Parse node) {
-    Set parents = new HashSet();
-    Parse parent = node.getParent();
-    do {
-      parents.add(parent);
-      parent = parent.getParent();
-    }
-    while(parent.getType().equals(node.getType()));
-    return parents;
-  }
-  */
 
   @Override
   protected boolean lastChild(Parse child, Parse parent) {
@@ -137,7 +154,6 @@ public class ParserEventStream extends AbstractParserEventStream {
       chunks[ci].setLabel(Parser.COMPLETE);
     }
     for (int ci = 0; ci < chunks.length; ci++) {
-      //System.err.println("parserEventStream.addParseEvents: chunks="+Arrays.asList(chunks));
       Parse parent = chunks[ci].getParent();
       Parse prevParent = chunks[ci];
       int off = 0;
@@ -149,7 +165,9 @@ public class ParserEventStream extends AbstractParserEventStream {
       while (!parent.getType().equals(AbstractBottomUpParser.TOP_NODE) && parent.getLabel() == null) {
         if (!prevParent.getType().equals(parent.getType())) {
           //build level
-          if (debug) System.err.println("Build: " + parent.getType() + " for: " + currentChunks[ci]);
+          if (logger.isDebugEnabled()) {
+            logger.debug("Build: {} for: {}", parent.getType(), currentChunks[ci]);
+          }
           if (etype == ParserEventTypeEnum.BUILD) {
             parseEvents.add(new Event(parent.getType(),
                 buildContextGenerator.getContext(currentChunks, ci)));
@@ -182,7 +200,6 @@ public class ParserEventStream extends AbstractParserEventStream {
           }
 
           chunks[ci] = parent;
-          //System.err.println("build: "+newParent+" for "+parent);
         }
         //TODO: Consider whether we need to set this label or train parses at all.
         parent.setLabel(Parser.BUILT);
@@ -207,8 +224,8 @@ public class ParserEventStream extends AbstractParserEventStream {
         /* Right frontier consisting of partially-built nodes based on current state of the parse.*/
         List<Parse> currentRightFrontier = Parser.getRightFrontier(currentChunks[0],punctSet);
         if (currentRightFrontier.size() != rightFrontier.size()) {
-          System.err.println("fontiers mis-aligned: " + currentRightFrontier.size() + " != "
-              + rightFrontier.size() + " " + currentRightFrontier + " " + rightFrontier);
+          logger.error("Frontiers mis-aligned: {} != {} {} {}", currentRightFrontier.size(),
+              rightFrontier.size(), currentRightFrontier, rightFrontier);
           System.exit(1);
         }
         Map<Parse, Integer> parents = getNonAdjoinedParent(chunks[ci]);
@@ -218,11 +235,11 @@ public class ParserEventStream extends AbstractParserEventStream {
           Parse cfn = currentRightFrontier.get(cfi);
           if (!Parser.checkComplete || !Parser.COMPLETE.equals(cfn.getLabel())) {
             Integer i = parents.get(frontierNode);
-            if (debug)
-              System.err.println("Looking at attachment site (" + cfi + "): "
-                  + cfn.getType() + " ci=" + i + " cs=" + nonPunctChildCount(cfn)
-                  + ", " + cfn + " :for " + currentChunks[ci].getType() + " "
-                  + currentChunks[ci] + " -> " + parents);
+            if (logger.isDebugEnabled())
+              logger.debug("Looking at attachment site ({}): {} ci={} cs={}, {} :for {} {} -> {}",
+                  cfi, cfn.getType(), i, nonPunctChildCount(cfn), cfn, currentChunks[ci].getType(),
+                  currentChunks[ci], parents
+              );
 
             if (attachNode == null &&  i != null && i == nonPunctChildCount(cfn)) {
               attachType = Parser.ATTACH_DAUGHTER;
@@ -232,18 +249,17 @@ public class ParserEventStream extends AbstractParserEventStream {
                 parseEvents.add(new Event(attachType, attachContextGenerator.getContext(currentChunks,
                     ci, currentRightFrontier, attachNodeIndex)));
               }
-              //System.err.println("daughter attach "+attachNode+" at "+fi);
             }
           }
           else {
-            if (debug)
-              System.err.println("Skipping (" + cfi + "): " + cfn.getType() + ","
-                  + cfn.getPreviousPunctuationSet() + " " + cfn + " :for "
-                  + currentChunks[ci].getType() + " " + currentChunks[ci] + " -> " + parents);
+            if (logger.isDebugEnabled())
+              logger.debug("Skipping ({}): {},{} {} :for {} {} -> {}",
+                  cfi, cfn.getType(), cfn.getPreviousPunctuationSet(), cfn,
+                  currentChunks[ci].getType(), currentChunks[ci], parents);
           }
           // Can't attach past first incomplete node.
           if (Parser.checkComplete && cfn.getLabel().equals(Parser.INCOMPLETE)) {
-            if (debug) System.err.println("breaking on incomplete:" + cfn.getType() + " " + cfn);
+            if (logger.isDebugEnabled()) logger.debug("breaking on incomplete: {} {}",  cfn.getType(), cfn);
             break;
           }
         }
@@ -262,7 +278,6 @@ public class ParserEventStream extends AbstractParserEventStream {
                   attachContextGenerator.getContext(currentChunks, ci, currentRightFrontier, cfi)));
             }
             chunks[ci].getParent().setLabel(Parser.BUILT);
-            //System.err.println("in search sister attach "+attachNode+" at "+cfi);
           }
           else if (cfi == attachNodeIndex) {
             //skip over previously attached daughter.
@@ -275,7 +290,7 @@ public class ParserEventStream extends AbstractParserEventStream {
           }
           //Can't attach past first incomplete node.
           if (Parser.checkComplete && cfn.getLabel().equals(Parser.INCOMPLETE)) {
-            if (debug) System.err.println("breaking on incomplete:" + cfn.getType() + " " + cfn);
+            if (logger.isDebugEnabled()) logger.debug("breaking on incomplete: {} {}",  cfn.getType(), cfn);
             break;
           }
         }
@@ -283,10 +298,9 @@ public class ParserEventStream extends AbstractParserEventStream {
         if (attachNode != null) {
           if (Parser.ATTACH_DAUGHTER.equals(attachType)) {
             Parse daughter = currentChunks[ci];
-            if (debug)
-              System.err.println("daughter attach a=" + attachNode.getType() + ":"
-                  + attachNode + " d=" + daughter + " com="
-                  + lastChild(chunks[ci], rightFrontier.get(attachNodeIndex)));
+            if (logger.isDebugEnabled())
+              logger.debug("daughter attach a={}:{} d={} com={}", attachNode.getType(),
+                  attachNode, daughter, lastChild(chunks[ci], rightFrontier.get(attachNodeIndex)));
 
             attachNode.add(daughter,rules);
             daughter.setParent(attachNode);
@@ -308,10 +322,10 @@ public class ParserEventStream extends AbstractParserEventStream {
             Parse frontierNode = rightFrontier.get(attachNodeIndex);
             rightFrontier.set(attachNodeIndex,frontierNode.getParent());
             Parse sister = currentChunks[ci];
-            if (debug)
-              System.err.println("sister attach a=" + attachNode.getType()
-                + ":" + attachNode + " s=" + sister + " ap=" + attachNode.getParent()
-                + " com=" + lastChild(chunks[ci], rightFrontier.get(attachNodeIndex)));
+            if (logger.isDebugEnabled())
+              logger.debug("sister attach a={}:{} s={} ap={} com={}", attachNode.getType(),
+                  attachNode, sister, attachNode.getParent(),
+                  lastChild(chunks[ci], rightFrontier.get(attachNodeIndex)));
 
             Parse newParent = attachNode.getParent().adjoin(sister,rules);
 
@@ -339,12 +353,10 @@ public class ParserEventStream extends AbstractParserEventStream {
           }
           //update right frontier
           for (int ni = 0; ni < attachNodeIndex; ni++) {
-            //System.err.println("removing: "+rightFrontier.get(0));
             rightFrontier.remove(0);
           }
         }
         else {
-          //System.err.println("No attachment!");
           throw new RuntimeException("No Attachment: " + chunks[ci]);
         }
       }
