@@ -19,6 +19,7 @@ package opennlp.tools.postag;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -49,15 +50,22 @@ import opennlp.tools.util.TrainingParameters;
 import opennlp.tools.util.featuregen.StringPattern;
 
 /**
- * A {@link POSTagger part-of-speech tagger} that uses maximum entropy.
+ * A {@link POSTagger part-of-speech tagger} implementation that uses maximum entropy.
  * <p>
- * Tries to predict whether words are nouns, verbs, or any of 70 other POS tags
+ * Tries to predict whether words are nouns, verbs, or any other {@link POSTagFormat POS tags}
  * depending on their surrounding context.
+ *
+ * @see POSModel
+ * @see POSTagFormat
+ * @see POSTagger
  */
 public class POSTaggerME implements POSTagger {
 
   private static final Logger logger = LoggerFactory.getLogger(POSTaggerME.class);
 
+  /**
+   * The default beam size value is 3.
+   */
   public static final int DEFAULT_BEAM_SIZE = 3;
 
   private final POSModel modelPackage;
@@ -65,7 +73,7 @@ public class POSTaggerME implements POSTagger {
   /**
    * The {@link POSContextGenerator feature context generator}.
    */
-  protected final POSContextGenerator contextGen;
+  protected final POSContextGenerator cg;
 
   /**
    * {@link TagDictionary} used for restricting words to a fixed set of tags.
@@ -79,20 +87,35 @@ public class POSTaggerME implements POSTagger {
 
   private Sequence bestSequence;
 
-  private final SequenceClassificationModel<String> model;
+  private final SequenceClassificationModel model;
 
   private final SequenceValidator<String> sequenceValidator;
 
+  private final POSTagFormat posTagFormat;
+
+  protected final POSTagFormatMapper posTagFormatMapper;
+
   /**
    * Initializes a {@link POSTaggerME} by downloading a default model for a given
    * {@code language}.
    *
    * @param language An ISO conform language code.
-   *                 
    * @throws IOException Thrown if the model could not be downloaded or saved.
    */
   public POSTaggerME(String language) throws IOException {
-    this(DownloadUtil.downloadModel(language, DownloadUtil.ModelType.POS, POSModel.class));
+    this(language, POSTagFormat.UD);
+  }
+
+  /**
+   * Initializes a {@link POSTaggerME} by downloading a default model for a given
+   * {@code language}.
+   *
+   * @param language An ISO conform language code.
+   * @param format   A valid {@link POSTagFormat}.
+   * @throws IOException Thrown if the model could not be downloaded or saved.
+   */
+  public POSTaggerME(String language, POSTagFormat format) throws IOException {
+    this(DownloadUtil.downloadModel(language, DownloadUtil.ModelType.POS, POSModel.class), format);
   }
 
   /**
@@ -101,6 +124,17 @@ public class POSTaggerME implements POSTagger {
    * @param model A valid {@link POSModel}.
    */
   public POSTaggerME(POSModel model) {
+    this(model, POSTagFormat.UD);
+  }
+
+  /**
+   * Initializes a {@link POSTaggerME} with the provided {@link POSModel model}.
+   *
+   * @param model  A valid {@link POSModel}.
+   * @param format A valid {@link POSTagFormat}.
+   */
+  public POSTaggerME(POSModel model, POSTagFormat format) {
+    this.posTagFormat = format;
     POSTaggerFactory factory = model.getFactory();
 
     int beamSize = POSTaggerME.DEFAULT_BEAM_SIZE;
@@ -113,7 +147,7 @@ public class POSTaggerME implements POSTagger {
 
     modelPackage = model;
 
-    contextGen = factory.getPOSContextGenerator(beamSize);
+    cg = factory.getPOSContextGenerator(beamSize);
     tagDictionary = factory.getTagDictionary();
     size = beamSize;
 
@@ -121,11 +155,13 @@ public class POSTaggerME implements POSTagger {
 
     if (model.getPosSequenceModel() != null) {
       this.model = model.getPosSequenceModel();
+    } else {
+      this.model = new BeamSearch(beamSize, model.getArtifact(POSModel.POS_MODEL_ENTRY_NAME), 0);
     }
-    else {
-      this.model = new opennlp.tools.ml.BeamSearch<>(beamSize,
-          model.getPosModel(), 0);
-    }
+
+    this.posTagFormatMapper = (format == POSTagFormat.CUSTOM)
+        ? new POSTagFormatMapper.NoOp()
+        : new POSTagFormatMapper(getAllPosTags());
 
   }
 
@@ -136,49 +172,70 @@ public class POSTaggerME implements POSTagger {
     return model.getOutcomes();
   }
 
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public String[] tag(String[] sentence) {
     return this.tag(sentence, null);
   }
 
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public String[] tag(String[] sentence, Object[] additionalContext) {
-    bestSequence = model.bestSequence(sentence, additionalContext, contextGen, sequenceValidator);
-    List<String> t = bestSequence.getOutcomes();
-    return t.toArray(new String[0]);
+    bestSequence = model.bestSequence(sentence, additionalContext, cg, sequenceValidator);
+    final List<String> t = bestSequence.getOutcomes();
+    return convertTags(t);
   }
 
   /**
    * Returns at most the specified {@code numTaggings} for the specified {@code sentence}.
    *
    * @param numTaggings The number of tagging to be returned.
-   * @param sentence An array of tokens which make up a sentence.
-   *
+   * @param sentence    An array of tokens which make up a sentence.
    * @return At most the specified number of taggings for the specified {@code sentence}.
    */
   public String[][] tag(int numTaggings, String[] sentence) {
     Sequence[] bestSequences = model.bestSequences(numTaggings, sentence, null,
-        contextGen, sequenceValidator);
+            cg, sequenceValidator);
     String[][] tags = new String[bestSequences.length][];
     for (int si = 0; si < tags.length; si++) {
       List<String> t = bestSequences[si].getOutcomes();
-      tags[si] = t.toArray(new String[0]);
+      tags[si] = convertTags(t);
     }
     return tags;
   }
 
+  private String[] convertTags(List<String> t) {
+    if (posTagFormat == POSTagFormat.CUSTOM
+        || posTagFormatMapper.getGuessedFormat() == posTagFormat) {
+      return t.toArray(new String[0]);
+    } else {
+      return posTagFormatMapper.convertTags(t);
+    }
+  }
+
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public Sequence[] topKSequences(String[] sentence) {
     return this.topKSequences(sentence, null);
   }
 
+  /**
+   * {@inheritDoc}
+   */
   @Override
   public Sequence[] topKSequences(String[] sentence, Object[] additionalContext) {
-    return model.bestSequences(size, sentence, additionalContext, contextGen, sequenceValidator);
+    return model.bestSequences(size, sentence, additionalContext, cg, sequenceValidator);
   }
 
   /**
-   * Populates the specified array with the probabilities for each tag of the last tagged sentence.
+   * Populates the specified {@code probs} array with the probabilities
+   * for each tag of the last tagged sentence.
    *
    * @param probs An array to put the probabilities into.
    */
@@ -194,18 +251,16 @@ public class POSTaggerME implements POSTagger {
   }
 
   public String[] getOrderedTags(List<String> words, List<String> tags, int index) {
-    return getOrderedTags(words,tags,index,null);
+    return getOrderedTags(words, tags, index, null);
   }
 
-  public String[] getOrderedTags(List<String> words, List<String> tags, int index,double[] tprobs) {
+  public String[] getOrderedTags(List<String> words, List<String> tags, int index, double[] tprobs) {
 
-    if (modelPackage.getPosModel() != null) {
+    MaxentModel posModel = modelPackage.getArtifact(POSModel.POS_MODEL_ENTRY_NAME);
+    if (posModel != null) {
 
-      MaxentModel posModel = modelPackage.getPosModel();
-
-      double[] probs = posModel.eval(contextGen.getContext(index,
-          words.toArray(new String[0]),
-          tags.toArray(new String[0]),null));
+      double[] probs = posModel.eval(cg.getContext(index, words.toArray(new String[0]),
+          tags.toArray(new String[0]), null));
 
       String[] orderedTags = new String[probs.length];
       for (int i = 0; i < probs.length; i++) {
@@ -221,58 +276,63 @@ public class POSTaggerME implements POSTagger {
         }
         probs[max] = 0;
       }
-      return orderedTags;
-    }
-    else {
+      return convertTags(Arrays.stream(orderedTags).toList());
+    } else {
       throw new UnsupportedOperationException("This method can only be called if the "
           + "classification model is an event model!");
     }
   }
 
-  public static POSModel train(String languageCode,
-      ObjectStream<POSSample> samples, TrainingParameters trainParams,
-      POSTaggerFactory posFactory) throws IOException {
+  /**
+   * Starts a training of a {@link POSModel} with the given parameters.
+   *
+   * @param languageCode  The ISO language code to train the model. Must not be {@code null}.
+   * @param samples       The {@link ObjectStream} of {@link POSSample} used as input for training.
+   * @param mlParams      The {@link TrainingParameters} for the context of the training process.
+   * @param posFactory    The {@link POSTaggerFactory} for creating related objects as defined
+   *                      via {@code mlParams}.
+   *
+   * @return A valid, trained {@link POSModel} instance.
+   * @throws IOException Thrown if IO errors occurred.
+   */
+  public static POSModel train(String languageCode, ObjectStream<POSSample> samples,
+                               TrainingParameters mlParams, POSTaggerFactory posFactory)
+      throws IOException {
 
-    int beamSize = trainParams.getIntParameter(BeamSearch.BEAM_SIZE_PARAMETER, POSTaggerME.DEFAULT_BEAM_SIZE);
+    final int beamSize = mlParams.getIntParameter(
+            BeamSearch.BEAM_SIZE_PARAMETER, POSTaggerME.DEFAULT_BEAM_SIZE);
 
-    POSContextGenerator contextGenerator = posFactory.getPOSContextGenerator();
-
-    Map<String, String> manifestInfoEntries = new HashMap<>();
-
-    TrainerType trainerType = TrainerFactory.getTrainerType(trainParams);
+    final POSContextGenerator contextGenerator = posFactory.getPOSContextGenerator();
+    final TrainerType trainerType = TrainerFactory.getTrainerType(mlParams);
+    final Map<String, String> manifestInfoEntries = new HashMap<>();
 
     MaxentModel posModel = null;
-    SequenceClassificationModel<String> seqPosModel = null;
+    SequenceClassificationModel seqPosModel = null;
     if (TrainerType.EVENT_MODEL_TRAINER.equals(trainerType)) {
       ObjectStream<Event> es = new POSSampleEventStream(samples, contextGenerator);
 
-      EventTrainer trainer = TrainerFactory.getEventTrainer(trainParams,
-          manifestInfoEntries);
+      EventTrainer trainer = TrainerFactory.getEventTrainer(mlParams, manifestInfoEntries);
       posModel = trainer.train(es);
-    }
-    else if (TrainerType.EVENT_MODEL_SEQUENCE_TRAINER.equals(trainerType)) {
+    } else if (TrainerType.EVENT_MODEL_SEQUENCE_TRAINER.equals(trainerType)) {
       POSSampleSequenceStream ss = new POSSampleSequenceStream(samples, contextGenerator);
       EventModelSequenceTrainer<POSSample> trainer =
-          TrainerFactory.getEventModelSequenceTrainer(trainParams, manifestInfoEntries);
+          TrainerFactory.getEventModelSequenceTrainer(mlParams, manifestInfoEntries);
       posModel = trainer.train(ss);
-    }
-    else if (TrainerType.SEQUENCE_TRAINER.equals(trainerType)) {
+    } else if (TrainerType.SEQUENCE_TRAINER.equals(trainerType)) {
       SequenceTrainer trainer = TrainerFactory.getSequenceModelTrainer(
-          trainParams, manifestInfoEntries);
+          mlParams, manifestInfoEntries);
 
       // TODO: This will probably cause issue, since the feature generator uses the outcomes array
 
       POSSampleSequenceStream ss = new POSSampleSequenceStream(samples, contextGenerator);
       seqPosModel = trainer.train(ss);
-    }
-    else {
+    } else {
       throw new IllegalArgumentException("Trainer type is not supported: " + trainerType);
     }
 
     if (posModel != null) {
       return new POSModel(languageCode, posModel, beamSize, manifestInfoEntries, posFactory);
-    }
-    else {
+    } else {
       return new POSModel(languageCode, seqPosModel, manifestInfoEntries, posFactory);
     }
   }
@@ -282,9 +342,7 @@ public class POSTaggerME implements POSTagger {
    *
    * @param samples The {@link ObjectStream} to process.
    * @param cutoff  A non-negative cut-off value.
-   *
    * @return A valid {@link Dictionary} instance holding nGrams.
-   *
    * @throws IOException Thrown if IO errors occurred during dictionary construction.
    */
   public static Dictionary buildNGramDictionary(ObjectStream<POSSample> samples, int cutoff)
@@ -295,8 +353,9 @@ public class POSTaggerME implements POSTagger {
     while ((sample = samples.read()) != null) {
       String[] words = sample.getSentence();
 
-      if (words.length > 0)
+      if (words.length > 0) {
         ngramModel.add(new StringList(words), 1, 1);
+      }
     }
 
     ngramModel.cutoff(cutoff, Integer.MAX_VALUE);
@@ -308,13 +367,12 @@ public class POSTaggerME implements POSTagger {
    * Populates a {@link POSDictionary} from an {@link ObjectStream} of samples.
    *
    * @param samples The {@link ObjectStream} to process.
-   * @param dict The {@link MutableTagDictionary} to use during population.
+   * @param dict    The {@link MutableTagDictionary} to use during population.
    * @param cutoff  A non-negative cut-off value.
-   *
    * @throws IOException Thrown if IO errors occurred during dictionary construction.
    */
   public static void populatePOSDictionary(ObjectStream<POSSample> samples,
-      MutableTagDictionary dict, int cutoff) throws IOException {
+                                           MutableTagDictionary dict, int cutoff) throws IOException {
 
     logger.info("Expanding POS Dictionary ...");
     long start = System.nanoTime();
@@ -371,12 +429,11 @@ public class POSTaggerME implements POSTagger {
           tagsForWord.add(entry.getKey());
         }
       }
-      if (tagsForWord.size() > 0) {
-        dict.put(wordEntry.getKey(),
-            tagsForWord.toArray(new String[0]));
+      if (!tagsForWord.isEmpty()) {
+        dict.put(wordEntry.getKey(), tagsForWord.toArray(new String[0]));
       }
     }
 
-    logger.info("... finished expanding POS Dictionary. [ {} ms]", (System.nanoTime() - start) / 1000000 );
+    logger.info("... finished expanding POS Dictionary. [ {} ms]", (System.nanoTime() - start) / 1000000);
   }
 }
