@@ -83,7 +83,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
       return "<CR>";
     }
 
-    return new String(new char[]{c});
+    return String.valueOf(c);
   }
 
   @Override
@@ -175,7 +175,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
     buf.append(prefix);
     collectFeats.add(buf.toString());
     buf.setLength(0);
-    if (!prefix.equals("")) {
+    if (!prefix.isEmpty()) {
       collectFeats.add(Integer.toString(prefix.length()));
       if (isFirstUpper(prefix)) {
         collectFeats.add("xcap");
@@ -189,7 +189,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
     buf.append(previous);
     collectFeats.add(buf.toString());
     buf.setLength(0);
-    if (!previous.equals("")) {
+    if (!previous.isEmpty()) {
       if (isFirstUpper(previous)) {
         collectFeats.add("vcap");
       }
@@ -202,7 +202,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
     buf.append(suffix);
     collectFeats.add(buf.toString());
     buf.setLength(0);
-    if (!suffix.equals("")) {
+    if (!suffix.isEmpty()) {
       if (isFirstUpper(suffix)) {
         collectFeats.add("scap");
       }
@@ -215,7 +215,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
     buf.append(next);
     collectFeats.add(buf.toString());
     buf.setLength(0);
-    if (!next.equals("")) {
+    if (!next.isEmpty()) {
       if (isFirstUpper(next)) {
         collectFeats.add("ncap");
       }
@@ -232,15 +232,15 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
   /**
    * Finds the index of the nearest space before a specified index which is not itself preceded by a space.
    *
-   * @param sb   The string buffer which contains the text being examined.
+   * @param sb   The {@link CharSequence} which contains the text being examined.
    * @param seek The index to begin searching from.
    * @return The index which contains the nearest space.
    */
   private static int previousSpaceIndex(CharSequence sb, int seek) {
-    seek--;
-    while (seek > 0 && !StringUtil.isWhitespace(sb.charAt(seek))) {
+    do {
       seek--;
-    }
+    } while (seek > 0 && !StringUtil.isWhitespace(sb.charAt(seek)));
+
     if (seek > 0 && StringUtil.isWhitespace(sb.charAt(seek))) {
       while (seek > 0 && StringUtil.isWhitespace(sb.charAt(seek - 1)))
         seek--;
@@ -252,7 +252,7 @@ public class DefaultSDContextGenerator implements SDContextGenerator {
   /**
    * Finds the index of the nearest space after a specified index.
    *
-   * @param sb The string buffer which contains the text being examined.
+   * @param sb The {@link CharSequence} which contains the text being examined.
    * @param seek The index to begin searching from.
    * @param lastIndex The highest index of the StringBuffer sb.
    * @return The index which contains the nearest space.
