@@ -18,18 +18,23 @@
 
 package opennlp.tools.util.normalizer;
 
+/**
+ * A {@link CharSequenceNormalizer} implementation that aggregates the
+ * functionality of other normalizers.
+ */
 public class AggregateCharSequenceNormalizer implements CharSequenceNormalizer {
 
+  private static final long serialVersionUID = 5514902020184083235L;
   private final CharSequenceNormalizer[] normalizers;
 
   public AggregateCharSequenceNormalizer(CharSequenceNormalizer ... normalizers) {
     this.normalizers = normalizers;
   }
 
+  @Override
   public CharSequence normalize (CharSequence text) {
 
-    for (CharSequenceNormalizer normalizers :
-        normalizers) {
+    for (CharSequenceNormalizer normalizers : normalizers) {
       text = normalizers.normalize(text);
     }
 
