@@ -25,7 +25,6 @@ import java.io.StringReader;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
-import opennlp.tools.util.InvalidFormatException;
 import opennlp.tools.util.StringList;
 
 /**
@@ -63,7 +62,7 @@ public class DictionaryTest {
 
     Assertions.assertTrue(dict.contains(entry1));
     Assertions.assertTrue(dict.contains(entry1u));
-    Assertions.assertTrue(!dict.contains(entry2));
+    Assertions.assertFalse(dict.contains(entry2));
   }
 
   /**
@@ -80,15 +79,14 @@ public class DictionaryTest {
     dict.put(entry1);
 
     Assertions.assertTrue(dict.contains(entry1));
-    Assertions.assertTrue(!dict.contains(entry1u));
-    Assertions.assertTrue(!dict.contains(entry2));
+    Assertions.assertFalse(dict.contains(entry1u));
+    Assertions.assertFalse(dict.contains(entry2));
   }
 
   /**
    * Tests serialization and deserailization of the {@link Dictionary}.
    *
-   * @throws IOException
-   * @throws InvalidFormatException
+   * @throws IOException Thrown if IO errors occurred.
    */
   @Test
   void testSerialization() throws IOException {
@@ -108,14 +106,14 @@ public class DictionaryTest {
     Dictionary recreated = new Dictionary(
         new ByteArrayInputStream(out.toByteArray()));
 
-    Assertions.assertTrue(reference.equals(recreated));
+    Assertions.assertEquals(reference, recreated);
   }
 
   /**
    * Tests for the {@link Dictionary#parseOneEntryPerLine(java.io.Reader)}
    * method.
    *
-   * @throws IOException
+   * @throws IOException Thrown if IO errors occurred.
    */
   @Test
   void testParseOneEntryPerLine() throws IOException {
@@ -125,7 +123,7 @@ public class DictionaryTest {
     Dictionary dictionay =
         Dictionary.parseOneEntryPerLine(new StringReader(testDictionary));
 
-    Assertions.assertTrue(dictionay.size() == 4);
+    Assertions.assertEquals(4, dictionay.size());
     Assertions.assertTrue(dictionay.contains(new StringList("1a", "1b", "1c", "1d")));
     Assertions.assertTrue(dictionay.contains(new StringList("2a", "2b", "2c")));
     Assertions.assertTrue(dictionay.contains(new StringList(new String[] {"3a"})));
@@ -152,9 +150,9 @@ public class DictionaryTest {
     dictC.put(entry1);
     dictC.put(entry2);
 
-    Assertions.assertTrue(dictA.equals(dictB));
-    Assertions.assertTrue(dictC.equals(dictA));
-    Assertions.assertTrue(dictB.equals(dictC));
+    Assertions.assertEquals(dictA, dictB);
+    Assertions.assertEquals(dictC, dictA);
+    Assertions.assertEquals(dictB, dictC);
   }
 
   /**
@@ -227,7 +225,7 @@ public class DictionaryTest {
 
     dict.put(entry1);
 
-    Assertions.assertTrue(!dict.contains(entry2));
+    Assertions.assertFalse(dict.contains(entry2));
   }
 
 }
