@@ -17,15 +17,13 @@
 
 package opennlp.tools.formats.brat;
 
-import java.io.File;
 import java.io.FileFilter;
 import java.io.IOException;
 import java.util.Collections;
-import java.util.HashMap;
-import java.util.Map;
 import java.util.Set;
 
 import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
 import opennlp.tools.namefind.NameSample;
@@ -33,22 +31,11 @@ import opennlp.tools.sentdetect.NewlineSentenceDetector;
 import opennlp.tools.tokenize.WhitespaceTokenizer;
 import opennlp.tools.util.ObjectStream;
 
-public class BratNameSampleStreamTest {
+public class BratNameSampleStreamTest extends AbstractBratTest {
 
-  private BratNameSampleStream createNameSampleWith(String nameContainsFilter,
-                                                    Set<String> nameTypes) throws IOException {
-    Map<String, String> typeToClassMap = new HashMap<>();
-    BratAnnotationStreamTest.addEntityTypes(typeToClassMap);
-    AnnotationConfiguration config = new AnnotationConfiguration(typeToClassMap);
-
-    File dir = new File(this.getClass().getResource("/opennlp/tools/formats/brat/").getFile());
-    FileFilter fileFilter = pathname -> pathname.getName().contains(nameContainsFilter);
-
-    ObjectStream<BratDocument> bratDocumentStream = new BratDocumentStream(config, dir,
-        false, fileFilter);
-
-    return new BratNameSampleStream(new NewlineSentenceDetector(),
-        WhitespaceTokenizer.INSTANCE, bratDocumentStream, nameTypes);
+  @BeforeEach
+  public void setup() throws IOException {
+    super.setup();
   }
 
   @Test
@@ -74,6 +61,7 @@ public class BratNameSampleStreamTest {
       NameSample sample = stream.read();
       while (sample != null) {
         sample = stream.read();
+        Assertions.assertNotNull(sample);
       }
     });
 
@@ -81,10 +69,8 @@ public class BratNameSampleStreamTest {
 
   @Test
   void emptySample() {
-    Assertions.assertThrows(IllegalArgumentException.class, () -> {
-      createNameSampleWith("overlapping",
-          Collections.emptySet());
-    });
+    Assertions.assertThrows(IllegalArgumentException.class, () -> createNameSampleWith("overlapping",
+        Collections.emptySet()));
   }
 
   @Test
@@ -100,4 +86,16 @@ public class BratNameSampleStreamTest {
 
     Assertions.assertEquals(8, count);
   }
+
+  private BratNameSampleStream createNameSampleWith(String nameContainsFilter,
+                                                    Set<String> nameTypes) throws IOException {
+    AnnotationConfiguration config = new AnnotationConfiguration(typeToClassMap);
+    FileFilter fileFilter = pathname -> pathname.getName().contains(nameContainsFilter);
+
+    ObjectStream<BratDocument> bratDocumentStream =
+            new BratDocumentStream(config, directory, false, fileFilter);
+
+    return new BratNameSampleStream(new NewlineSentenceDetector(),
+            WhitespaceTokenizer.INSTANCE, bratDocumentStream, nameTypes);
+  }
 }
