@@ -19,7 +19,6 @@ package opennlp.tools.langdetect;
 
 import java.util.concurrent.atomic.AtomicInteger;
 
-
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -48,8 +47,8 @@ public class LanguageDetectorCrossValidatorTest {
           }
 
           @Override
-          public void missclassified(LanguageSample reference,
-                                     LanguageSample prediction) {
+          public void misclassified(LanguageSample reference,
+                                    LanguageSample prediction) {
             incorrectCount.incrementAndGet();
           }
         });
